@@ -114,7 +114,7 @@ latticeStyleGUI <-
         } else {
             ## looks like the demo device has closed.
             ## start a new device
-            trellis.device(retain = TRUE)
+            trellis.device(new = TRUE, retain = TRUE)
             ## Note, retain = TRUE may not be enough because
             ## it may be a different device (eg Cairo vs X11)
             trellis.par.set(get("trellis.par.theme", globalenv()))
@@ -353,8 +353,9 @@ latticeStyleGUI <-
     if (inherits(guiToolkit(), "guiWidgetsToolkitRGtk2")) {
         ggraphics(width = width, height = height, ps = pointsize,
                   container = hgroup, expand = TRUE)
+    } else {
+        trellis.device(new = TRUE, retain = TRUE)
     }
-    trellis.device(new = FALSE, retain = TRUE) ## i.e. new device if needed
     par(ps = pointsize)
     ## set initial style from target device
     trellis.par.set(pars)
